@@ -1,7 +1,7 @@
 // SPDX-FileCopyrightText: 2022 Claudio Cambra <claudio.cambra@gmail.com>
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
-#include <filter.h>
+#include "filter.h"
 
 #include <QSignalSpy>
 #include <QTest>
