@@ -34,6 +34,8 @@ class UndoRedoData
 {
     Q_GADGET
     QML_VALUE_TYPE(undoRedoData)
+    QML_UNCREATABLE("")
+
     Q_PROPERTY(bool undoAvailable MEMBER undoAvailable)
     Q_PROPERTY(bool redoAvailable MEMBER redoAvailable)
     Q_PROPERTY(QString nextUndoDescription MEMBER nextUndoDescription)
@@ -106,11 +108,11 @@ public:
     Q_INVOKABLE QVariant getIncidenceSubclassed(KCalendarCore::Incidence::Ptr incidencePtr);
     Q_INVOKABLE void undoAction();
     Q_INVOKABLE void redoAction();
+    Q_INVOKABLE Akonadi::Collection getCollection(qint64 collectionId);
 
     Q_INVOKABLE void updateAllCollections();
     Q_INVOKABLE void updateCollection(qint64 collectionId);
     Q_INVOKABLE void deleteCollection(qint64 collectionId);
-    Q_INVOKABLE void editCollection(qint64 collectionId);
     Q_INVOKABLE void toggleCollection(qint64 collectionId);
 
 private Q_SLOTS:
@@ -124,6 +126,7 @@ Q_SIGNALS:
     void updateIncidenceDatesCompleted();
     void collectionColorsChanged();
     void incidenceAdded();
+    void errorOccurred(const QString &errorOccurred);
 
 private:
     Akonadi::ETMCalendar::Ptr m_calendar = nullptr;
