@@ -18,6 +18,60 @@
 #include <QByteArray>
 #include <QObject>
 #include <QPointer>
+#include <qqmlintegration.h>
+
+class MonthPosition
+{
+    Q_GADGET
+    Q_PROPERTY(int day MEMBER day)
+    Q_PROPERTY(int pos MEMBER pos)
+
+public:
+    int day;
+    int pos;
+
+    bool operator==(const MonthPosition &rhs) const
+    {
+        return day == rhs.day && pos == rhs.pos;
+    }
+};
+
+class RecurrenceData
+{
+    Q_GADGET
+    Q_PROPERTY(QList<bool> weekdays MEMBER weekdays)
+    Q_PROPERTY(int duration MEMBER duration)
+    Q_PROPERTY(int frequency MEMBER frequency)
+    Q_PROPERTY(QDateTime startDateTime MEMBER startDateTime)
+    Q_PROPERTY(QString startDateTimeDisplay MEMBER startDateTimeDisplay)
+    Q_PROPERTY(QDateTime endDateTime MEMBER endDateTime)
+    Q_PROPERTY(QString endDateTimeDisplay MEMBER endDateTimeDisplay)
+    Q_PROPERTY(QString endDateDisplay MEMBER endDateDisplay)
+    Q_PROPERTY(bool allDay MEMBER allDay)
+    Q_PROPERTY(ushort type MEMBER type)
+    Q_PROPERTY(QList<int> monthDays MEMBER monthDays)
+    Q_PROPERTY(QList<MonthPosition> monthPositions MEMBER monthPositions)
+    Q_PROPERTY(QList<int> yearDays MEMBER yearDays)
+    Q_PROPERTY(QList<int> yearDates MEMBER yearDates)
+    Q_PROPERTY(QList<int> yearMonths MEMBER yearMonths)
+
+public:
+    QList<bool> weekdays;
+    int duration;
+    int frequency;
+    QDateTime startDateTime;
+    QString startDateTimeDisplay;
+    QDateTime endDateTime;
+    QString endDateTimeDisplay;
+    QString endDateDisplay;
+    bool allDay;
+    ushort type;
+    QList<int> monthDays;
+    QList<MonthPosition> monthPositions;
+    QList<int> yearDays;
+    QList<int> yearDates;
+    QList<int> yearMonths;
+};
 
 /**
  * This class is a wrapper for a KCalendarCore::Incidence::Ptr object.
@@ -30,6 +84,8 @@
 class IncidenceWrapper : public QObject, public Akonadi::ItemMonitor
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_UNCREATABLE("")
 
     // Akonadi properties
     Q_PROPERTY(Akonadi::Item incidenceItem READ incidenceItem WRITE setIncidenceItem NOTIFY incidenceItemChanged)
@@ -70,7 +126,7 @@ class IncidenceWrapper : public QObject, public Akonadi::ItemMonitor
     Q_PROPERTY(int priority READ priority WRITE setPriority NOTIFY priorityChanged)
 
     Q_PROPERTY(KCalendarCore::Recurrence *recurrence READ recurrence NOTIFY incidencePtrChanged)
-    Q_PROPERTY(QVariantMap recurrenceData READ recurrenceData NOTIFY recurrenceDataChanged)
+    Q_PROPERTY(RecurrenceData recurrenceData READ recurrenceData NOTIFY recurrenceDataChanged)
     Q_PROPERTY(RecurrenceExceptionsModel *recurrenceExceptionsModel READ recurrenceExceptionsModel NOTIFY recurrenceExceptionsModelChanged)
 
     Q_PROPERTY(AttendeesModel *attendeesModel READ attendeesModel NOTIFY attendeesModelChanged)
@@ -155,7 +211,7 @@ public:
     [[nodiscard]] QString incidenceEndDateDisplay() const;
     [[nodiscard]] QString incidenceEndTimeDisplay() const;
     Q_INVOKABLE void setIncidenceTimeToNearestQuarterHour(bool setStartTime = true, bool setEndTime = true);
-    QByteArray timeZone() const;
+    [[nodiscard]] QByteArray timeZone() const;
     void setTimeZone(const QByteArray &timeZone);
     [[nodiscard]] int startTimeZoneUTCOffsetMins();
     [[nodiscard]] int endTimeZoneUTCOffsetMins();
@@ -167,7 +223,7 @@ public:
     void setPriority(int priority);
 
     KCalendarCore::Recurrence *recurrence() const;
-    QVariantMap recurrenceData();
+    RecurrenceData recurrenceData() const;
     Q_INVOKABLE void setRecurrenceDataItem(const QString &key, const QVariant &value);
 
     QVariantMap organizer();
