@@ -59,13 +59,13 @@ void ContactApplication::setupActions()
     auto action = new QAction(QIcon::fromTheme(u"edit-entry-symbolic"_s), i18nc("@action", "Edit contact…"), this);
     mainCollection()->addAction("contact_edit"_L1, action);
 
-    action = new QAction(QIcon::fromTheme(u"delete-symbolic"_s), i18nc("@action:inmenu", "Delete contact"), this);
+    action = new QAction(QIcon::fromTheme(u"delete-symbolic"_s), i18nc("@action", "Delete contact"), this);
     mainCollection()->addAction("contact_delete"_L1, action);
 
-    action = new QAction(QIcon::fromTheme(u"edit-move-symbolic"_s), i18nc("@action", "Move to..."), this);
+    action = new QAction(QIcon::fromTheme(u"edit-move-symbolic"_s), i18nc("@action", "Move to…"), this);
     mainCollection()->addAction("contact_move_to"_L1, action);
 
-    action = new QAction(QIcon::fromTheme(u"edit-copy-symbolic"_s), i18nc("@action", "Copy to..."), this);
+    action = new QAction(QIcon::fromTheme(u"edit-copy-symbolic"_s), i18nc("@action", "Copy to…"), this);
     mainCollection()->addAction("contact_copy_to"_L1, action);
 
     readSettings();
